
Consider semianalytical models of cosmic reionization. Develop equations for the ionization fraction of the universe or filling factor, and solve them analytically or numerically.
Constrain the possible solutions using the data from table 5.1 from the reference https://arxiv.org/pdf/2112.08201, which includes constraints on the ionization fraction of the universe, and other data if needed.
